@@ -116,15 +116,15 @@ sub init_runtime {
     $BUILDER_ENV = $builder_runtime->build_env;
     
     # Set command line info
-    $BUILDER_ENV->set_command_info_program_name($0);
-    $BUILDER_ENV->set_command_info_argv(\@ARGV);
+    $BUILDER_STACK = $BUILDER_ENV->build_stack;
+    
+    $BUILDER_ENV->set_command_info_program_name($BUILDER_STACK, $0);
+    $BUILDER_ENV->set_command_info_argv($BUILDER_STACK, \@ARGV);
     my $base_time = $^T + 0; # For Perl 5.8.9
-    $BUILDER_ENV->set_command_info_base_time($base_time);
+    $BUILDER_ENV->set_command_info_base_time($BUILDER_STACK, $base_time);
     
     # Call INIT blocks
-    $BUILDER_ENV->call_init_blocks;
-    
-    $BUILDER_STACK = $BUILDER_ENV->build_stack;
+    $BUILDER_ENV->call_init_blocks($BUILDER_STACK);
     
     $BUILDER_API = SPVM::ExchangeAPI->new(env => $BUILDER_ENV, stack => $BUILDER_STACK);
     
@@ -133,7 +133,7 @@ sub init_runtime {
       $COMPILER->add_class_path($class_path);
     }
     $RUNTIME = $COMPILER->build_runtime;
-
+    
     &load_dynamic_libs($RUNTIME, $DYNAMIC_LIB_FILES);
   }
 }
@@ -250,15 +250,15 @@ sub init_api {
   
   $ENV = $RUNTIME->build_env;
   
-  $ENV->set_command_info_program_name($0);
-  $ENV->set_command_info_argv(\@ARGV);
-  my $base_time = $^T + 0; # For Perl 5.8.9
-  $ENV->set_command_info_base_time($base_time);
-  
-  $ENV->call_init_blocks;
-  
   $STACK = $ENV->build_stack;
   
+  $ENV->set_command_info_program_name($STACK, $0);
+  $ENV->set_command_info_argv($STACK, \@ARGV);
+  my $base_time = $^T + 0; # For Perl 5.8.9
+  $ENV->set_command_info_base_time($STACK, $base_time);
+  
+  $ENV->call_init_blocks($STACK);
+  
   $API = SPVM::ExchangeAPI->new(env => $ENV, stack => $STACK);
 }
 
@@ -266,11 +266,17 @@ END {
   $BUILDER = undef;
   $COMPILER = undef;
   $API = undef;
+  if ($ENV) {
+    $ENV->cleanup_global_vars($STACK);
+  }
   $STACK = undef;
   $ENV = undef;
   $RUNTIME = undef;
   $DYNAMIC_LIB_FILES = undef;
   $BUILDER_API = undef;
+  if ($BUILDER_ENV) {
+    $BUILDER_ENV->cleanup_global_vars($BUILDER_STACK);
+  }
   $BUILDER_STACK = undef;
   $BUILDER_ENV = undef;
 }
